////////
/////////////////////////////////////////////////
// EEPROM.h

unsigned char EEPROMRead(unsigned char addr);
void EEPROMWrite(unsigned char data, unsigned char addr);

void EEPROMBlockRead(void *dest, unsigned char src, unsigned char len);
void EEPROMBlockWrite(unsigned char dest, void *src, unsigned char len);

extern struct EEPROMData
{
	unsigned int maxLight, minLight;
	char maxLightFixed, minLightFixed;
	
	// Keep this as the last piece of data, so that when new items are
	// added, they will be considered invalid until the new, grown
	// structure is initialized
	unsigned char invalid;
} eepromData;

// Write a specific field of eepromData to the EEPROM, e.g.:
//   EEPROMElementWrite(dstEnabled);
#define EEPROMElementWrite(elem) \
	EEPROMBlockWrite((char *) &(eepromData.elem) - (char *) &eepromData, \
		&(eepromData.elem), sizeof(eepromData.elem))

#define EEPROMArrayElementWrite(elem) \
	EEPROMBlockWrite((char *) eepromData.elem - (char *) &eepromData, \
		eepromData.elem, sizeof(eepromData.elem))

#define EEPROMElementsWrite(firstElem, lastElem) \
	EEPROMBlockWrite((char *) &eepromData.firstElem - (char *) &eepromData, \
		&eepromData.firstElem, \
		(char *) ((&eepromData.lastElem) + 1) - (char *) &eepromData.firstElem)
